import { LoggerService, AuthService, DiscoveryService } from '@backstage/backend-plugin-api';
import { RoadieVectorStore, AugmentationIndexer } from '@alithya-oss/plugin-rag-ai-node';
import { CatalogApi } from '@backstage/catalog-client';
import { AwsCredentialIdentity, Provider } from '@aws-sdk/types';
import { Config } from '@backstage/config';

/**
 * Amazon Bedrock client configuration to generate embeddings
 * @public
 */
interface RoadieBedrockEmbeddingsConfig {
    logger: LoggerService;
    auth: AuthService;
    vectorStore: RoadieVectorStore;
    catalogApi: CatalogApi;
    discovery: DiscoveryService;
    config: Config;
    options: {
        credentials: AwsCredentialIdentity | Provider<AwsCredentialIdentity>;
        region: string;
    };
}
/** @public */
declare function initializeBedrockEmbeddings({ logger, auth, vectorStore, catalogApi, discovery, config, options, }: RoadieBedrockEmbeddingsConfig): Promise<AugmentationIndexer>;

export { type RoadieBedrockEmbeddingsConfig, initializeBedrockEmbeddings };
